[PATCH] remove struct vio_dev's archdata

Stephen Rothwell sfr at canb.auug.org.au
Tue Jun 8 17:13:44 EST 2004


Hi Dave,

This patch is the restart of my VIO work.  This first patch just removes
vio_dev's archdata member and uses its dev.platform_data instead since it
is unused.  This simplifies a couple of bits of the code and reduces
struct vio_dev's size.

I also static'ed a couple of functions.

Please apply to the Ameslab tree if you think it is OK and have time.
--
Cheers,
Stephen Rothwell                    sfr at canb.auug.org.au
http://www.canb.auug.org.au/~sfr/
-------------- next part --------------
diff -ruN ppc64-linux-2.5/drivers/scsi/ibmvscsi/iseries_vscsi.c ppc64-linux-2.5.archdata/drivers/scsi/ibmvscsi/iseries_vscsi.c
--- ppc64-linux-2.5/drivers/scsi/ibmvscsi/iseries_vscsi.c	2004-05-22 10:04:35.000000000 +1000
+++ ppc64-linux-2.5.archdata/drivers/scsi/ibmvscsi/iseries_vscsi.c	2004-06-08 16:27:52.000000000 +1000
@@ -153,7 +153,6 @@

 int __init ibmvscsi_module_init(void)
 {
-	iseries_vscsi_dev.archdata = to_vio_dev(iSeries_vio_dev)->archdata;
 	iseries_vscsi_dev.iommu_table =
 		to_vio_dev(iSeries_vio_dev)->iommu_table;
 	if (device_register(&iseries_vscsi_dev.dev)) {
diff -ruN ppc64-linux-2.5/include/asm-ppc64/vio.h ppc64-linux-2.5.archdata/include/asm-ppc64/vio.h
--- ppc64-linux-2.5/include/asm-ppc64/vio.h	2004-04-13 18:06:17.000000000 +1000
+++ ppc64-linux-2.5.archdata/include/asm-ppc64/vio.h	2004-06-08 16:32:33.000000000 +1000
@@ -43,8 +43,6 @@

 int vio_register_driver(struct vio_driver *drv);
 void vio_unregister_driver(struct vio_driver *drv);
-const struct vio_device_id * vio_match_device(const struct vio_device_id *ids,
-						const struct vio_dev *dev);

 struct vio_dev * __devinit vio_register_device(struct device_node *node_vdev);
 void __devinit vio_unregister_device(struct vio_dev *dev);
@@ -52,7 +50,6 @@

 const void * vio_get_attribute(struct vio_dev *vdev, void* which, int* length);
 int vio_get_irq(struct vio_dev *dev);
-struct iommu_table * vio_build_iommu_table(struct vio_dev *dev);
 int vio_enable_interrupts(struct vio_dev *dev);
 int vio_disable_interrupts(struct vio_dev *dev);

@@ -110,7 +107,6 @@
  * The vio_dev structure is used to describe virtual I/O devices.
  */
 struct vio_dev {
-	struct device_node *archdata;   /* Open Firmware node */
 	void *driver_data;              /* data private to the driver */
 	struct iommu_table *iommu_table;     /* vio_map_* uses this */
 	uint32_t unit_address;


More information about the Linuxppc64-dev mailing list
diff -ruN ppc64-linux-2.5/arch/ppc64/kernel/vio.c ppc64-linux-2.5.archdata/arch/ppc64/kernel/vio.c
--- ppc64-linux-2.5/arch/ppc64/kernel/vio.c	2004-05-19 18:04:56.000000000 +1000
+++ ppc64-linux-2.5.archdata/arch/ppc64/kernel/vio.c	2004-06-08 17:04:51.000000000 +1000
@@ -32,7 +32,9 @@

 extern struct subsystem devices_subsys; /* needed for vio_find_name() */

-struct iommu_table *vio_build_iommu_table(struct vio_dev *dev);
+static struct iommu_table *vio_build_iommu_table(struct vio_dev *);
+static const struct vio_device_id *vio_match_device(
+		const struct vio_device_id *, const struct vio_dev *);

 #ifdef CONFIG_PPC_PSERIES
 static int vio_num_address_cells;
@@ -136,15 +138,15 @@
  * system is in its list of supported devices. Returns the matching
  * vio_device_id structure or NULL if there is no match.
  */
-const struct vio_device_id * vio_match_device(const struct vio_device_id *ids,
+static const struct vio_device_id * vio_match_device(const struct vio_device_id *ids,
 	const struct vio_dev *dev)
 {
 	DBGENTER();

 #ifdef CONFIG_PPC_PSERIES
 	while (ids->type) {
-		if ((strncmp(dev->archdata->type, ids->type, strlen(ids->type)) == 0) &&
-			device_is_compatible((struct device_node*)dev->archdata, ids->compat))
+		if ((strncmp(((struct device_node *)dev->dev.platform_data)->type, ids->type, strlen(ids->type)) == 0) &&
+			device_is_compatible(dev->dev.platform_data, ids->compat))
 			return ids;
 		ids++;
 	}
@@ -263,14 +265,13 @@
 	DBGENTER();

 	/* XXX free TCE table */
-	of_node_put(viodev->archdata);
+	of_node_put(viodev->dev.platform_data);
 	kfree(viodev);
 }

 static ssize_t viodev_show_devspec(struct device *dev, char *buf)
 {
-	struct vio_dev *viodev = to_vio_dev(dev);
-	struct device_node *of_node = viodev->archdata;
+	struct device_node *of_node = dev->platform_data;

 	return sprintf(buf, "%s\n", of_node->full_name);
 }
@@ -278,8 +279,7 @@

 static ssize_t viodev_show_name(struct device *dev, char *buf)
 {
-	struct vio_dev *viodev = to_vio_dev(dev);
-	struct device_node *of_node = viodev->archdata;
+	struct device_node *of_node = dev->platform_data;

 	return sprintf(buf, "%s\n", of_node->name);
 }
@@ -290,7 +290,7 @@
  * @of_node:	The OF node for this device.
  *
  * Creates and initializes a vio_dev structure from the data in
  * of_node (archdata) and adds it to the list of virtual devices.
  * Returns a pointer to the created vio_dev or NULL if node has
  * NULL device_type or compatible fields.
  */
@@ -324,7 +324,7 @@
 	}
 	memset(viodev, 0, sizeof(struct vio_dev));

-	viodev->archdata = (void *)of_node_get(of_node);
+	viodev->dev.platform_data = of_node_get(of_node);
 	viodev->unit_address = *unit_address;
 	viodev->iommu_table = vio_build_iommu_table(viodev);

@@ -380,7 +380,7 @@
 */
 const void * vio_get_attribute(struct vio_dev *vdev, void* which, int* length)
 {
-	return get_property((struct device_node *)vdev->archdata, (char*)which, length);
+	return get_property(vdev->dev.platform_data, (char*)which, length);
 }
 EXPORT_SYMBOL(vio_get_attribute);

@@ -427,7 +427,7 @@
  * Returns a pointer to the built tce tree, or NULL if it can't
  * find property.
 */
-struct iommu_table * vio_build_iommu_table(struct vio_dev *dev)
+static struct iommu_table * vio_build_iommu_table(struct vio_dev *dev)
 {
 	unsigned int *dma_window;
 	struct iommu_table *newTceTable;
@@ -435,7 +435,7 @@
 	unsigned long size;
 	int dma_window_property_size;

-	dma_window = (unsigned int *) get_property((struct device_node *)dev->archdata, "ibm,my-dma-window", &dma_window_property_size);
+	dma_window = (unsigned int *) get_property(dev->dev.platform_data, "ibm,my-dma-window", &dma_window_property_size);
 	if(!dma_window) {
 		return NULL;
 	}
@@ -290,7 +290,7 @@
  *
  * Creates and initializes a vio_dev structure from the data in
- * of_node (archdata) and adds it to the list of virtual devices.
+ * of_node (dev.platform_data) and adds it to the list of virtual devices.
  * Returns a pointer to the created vio_dev or NULL if node has
  * NULL device_type or compatible fields.